==> haskell-yesod-test-1.6.6-55-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-test
version: 1.6.6
id: yesod-test-1.6.6-LD8Y8HwYySLDkaEr3Yh3UN
key: yesod-test-1.6.6-LD8Y8HwYySLDkaEr3Yh3UN
license: MIT
maintainer: Michael Snoyman, Greg Weber, Nubis <nubis@woobiz.com.ar>
author: Nubis <nubis@woobiz.com.ar>
stability: Experimental
homepage: http://www.yesodweb.com
synopsis: integration testing for WAI/Yesod Applications
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-test>
category: Web, Yesod, Testing
abi: bead4c7fed739afd6969762e98397d24
exposed: True
exposed-modules:
    Yesod.Test Yesod.Test.CssQuery Yesod.Test.TransversingCSS
import-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-test-1.6.6
library-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-test-1.6.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yesod-test-1.6.6
hs-libraries: HSyesod-test-1.6.6-LD8Y8HwYySLDkaEr3Yh3UN
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
    attoparsec-0.13.2.2-3nUJVHBWBICGFmP4JcM3ay base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    blaze-html-0.9.1.1-A8LR7w4yS96GtRVO7i7OSl bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    conduit-1.3.1.1-IQr01ehJbIbFHxZqbcjBvx containers-0.6.0.1
    cookie-0.4.4-BFYr3M2B0n8F3gqLxXgKNx
    hspec-core-2.7.0-9NnDleZEH4rJ9g7wAFIQaO
    html-conduit-1.3.2-4BpWcGgG1bc38JSxlBJOAa
    http-types-0.12.3-FkUAYjCWW0WBZI2lM6bGTd
    network-2.8.0.0-g7zeLS1MQKFu6rNI1xGwt
    pretty-show-1.9.5-4s9IVBWSe01IF3L4DDRCg8 text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2 wai-3.2.2-GrHvuMWBg0KAzl6COLfHLZ
    wai-extra-3.0.25-9C75jqkXOQZ8OqSrgBEOK1
    xml-conduit-1.8.0.1-5BLQNM5qacD158eSPiGvla
    xml-types-0.3.6-56MQ2lbfiw31ognZ51DOah
    yesod-core-1.6.14-JgtSTP4YcgE3FYyZqk66am
haddock-interfaces: /usr/share/doc/haskell-yesod-test/html/yesod-test.haddock
haddock-html: /usr/share/doc/haskell-yesod-test/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-test-1.6.6-57-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-test
version: 1.6.6
id: yesod-test-1.6.6-KWQwyV2Myg96WCv2TmysCh
key: yesod-test-1.6.6-KWQwyV2Myg96WCv2TmysCh
license: MIT
maintainer: Michael Snoyman, Greg Weber, Nubis <nubis@woobiz.com.ar>
author: Nubis <nubis@woobiz.com.ar>
stability: Experimental
homepage: http://www.yesodweb.com
synopsis: integration testing for WAI/Yesod Applications
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-test>
category: Web, Yesod, Testing
abi: 0808c9988d492b7c8c5f27d1fa813d5a
exposed: True
exposed-modules:
    Yesod.Test Yesod.Test.CssQuery Yesod.Test.TransversingCSS
import-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-test-1.6.6
library-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-test-1.6.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yesod-test-1.6.6
hs-libraries: HSyesod-test-1.6.6-KWQwyV2Myg96WCv2TmysCh
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
    attoparsec-0.13.2.2-3nUJVHBWBICGFmP4JcM3ay base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    blaze-html-0.9.1.1-A8LR7w4yS96GtRVO7i7OSl bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    conduit-1.3.1.1-Jqkrz3R953b3ZlpJd9iBNU containers-0.6.0.1
    cookie-0.4.4-BFYr3M2B0n8F3gqLxXgKNx
    hspec-core-2.7.0-9NnDleZEH4rJ9g7wAFIQaO
    html-conduit-1.3.2-8RGfnDuleAk8VCgag4irpZ
    http-types-0.12.3-FkUAYjCWW0WBZI2lM6bGTd
    network-2.8.0.0-g7zeLS1MQKFu6rNI1xGwt
    pretty-show-1.9.5-4s9IVBWSe01IF3L4DDRCg8 text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2 wai-3.2.2-GrHvuMWBg0KAzl6COLfHLZ
    wai-extra-3.0.25-9C75jqkXOQZ8OqSrgBEOK1
    xml-conduit-1.8.0.1-ILUj1jsXyQq5kg9b718uuc
    xml-types-0.3.6-56MQ2lbfiw31ognZ51DOah
    yesod-core-1.6.14-HLJTT0Yn5IP6V5ktWj9g5I
haddock-interfaces: /usr/share/doc/haskell-yesod-test/html/yesod-test.haddock
haddock-html: /usr/share/doc/haskell-yesod-test/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
